RefactoringRope/CodeAssistClient.py

branch
eric7
changeset 365
f740b50380df
parent 362
792c2651fbd7
child 370
9d246420f284
--- a/RefactoringRope/CodeAssistClient.py	Wed May 26 17:53:08 2021 +0200
+++ b/RefactoringRope/CodeAssistClient.py	Wed May 26 19:07:42 2021 +0200
@@ -21,14 +21,10 @@
 except ImportError:
     sys.exit(42)
 
-try:
-    from eric6.E5Network.E5JsonClient import E5JsonClient
-except ImportError:
-    # TODO: delete JsonClient once ported to eric7
-    from JsonClient import JsonClient as E5JsonClient
+from eric7.EricNetwork.EricJsonClient import EricJsonClient
 
 
-class CodeAssistClient(E5JsonClient):
+class CodeAssistClient(EricJsonClient):
     """
     Class implementing the code assist client interface to rope.
     """
@@ -453,10 +449,10 @@
     
     host, port, idString, projectPath = sys.argv[1:-1]
     
     # Create a Qt5 application object in order to allow the processing of
     # modules containing Qt stuff.
     try:
-        from PyQt5.QtCore import QCoreApplication
+        from PyQt6.QtCore import QCoreApplication
     except ImportError:
         QCoreApplication = None
     if QCoreApplication is not None:
@@ -453,10 +449,10 @@
     host, port, idString, projectPath = sys.argv[1:-1]
     
-    # Create a Qt5 application object in order to allow the processing of
+    # Create a Qt6 application object in order to allow the processing of
     # modules containing Qt stuff.
     try:

eric ide

mercurial